==> kadu-2.1.tar.bz2: kadu-2.1/plugins/gadu_protocol/translations/gadu_protocol_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Unable to connect, server has not been found</source>
        <translation>Connexion impossible. Le serveur est introuvable</translation>
    </message>
    <message>
        <source>Unable to connect</source>
        <translation>Connexion impossible.</translation>
    </message>
    <message>
        <source>Please change your email in &quot;Change password / email&quot; window. Leave new password field blank.</source>
        <translation>Veuillez changer votre email dans la fenêtre &quot;changer mot de passe / email&quot;. Laissez le champ nouveau mot de passe à blanc.</translation>
    </message>
    <message>
        <source>Unable to connect, server has returned unknown data</source>
        <translation>Impossible de se connecter au serveur, le serveur a retourné des données inconnus</translation>
    </message>
    <message>
        <source>Unable to connect, connection break during reading</source>
        <translation>Impossible de se connecter au serveur, la connexion a été interrompu pendant la lecture</translation>
    </message>
    <message>
        <source>Unable to connect, connection break during writing</source>
        <translation>Impossible de se connecter au serveur, la connexion a été interrompu pendant la l&apos;écriture</translation>
    </message>
    <message>
        <source>Unable to connect, invalid password</source>
        <translation>Impossible de se connecter au serveur, mot de passe non valide</translation>
    </message>
    <message>
        <source>Unable to connect, error of negotiation TLS</source>
        <translation>Impossible de se connecter au serveur, erreur de négociation TLS</translation>
    </message>
    <message>
        <source>Too many connection attempts with bad password!</source>
        <translation>Trop de tentatives de connexions avec un mot de passe incorrect!</translation>
    </message>
    <message>
        <source>Unable to connect, servers are down</source>
        <translation>Impossible de se connecter au serveur, le serveur est indisponible</translation>
    </message>
    <message>
        <source>Connection broken</source>
        <translation>Connexion interrompue</translation>
    </message>
    <message>
        <source>Connection timeout!</source>
        <translation>délai de connexion!</translation>
    </message>
    <message>
        <source>Disconnection has occurred</source>
        <translation>Une déconnexion s&apos;est produite</translation>
    </message>
</context>
<context>
    <name>GaduAddAccountWidget</name>
    <message>
        <source>Gadu-Gadu number</source>
        <translation>Numéro Gadu-Gadu</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Remember Password</source>
        <translation>Rappeler le mot de passe</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Identité du compte</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt; Sélectionnez ou entrez l&apos;identité qui va être associée avec le compte &lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Add Account</source>
        <translation>Ajouter un compte</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulez</translation>
    </message>
    <message>
        <source>Register Account</source>
        <translation>Inscription de compte</translation>
    </message>
    <message>
        <source>Remind GG number</source>
        <translation>Mémoriser nombre GG</translation>
    </message>
    <message>
        <source>Remind Password</source>
        <translation>Retenir le mot de passe</translation>
    </message>
</context>
<context>
    <name>GaduChatImageService</name>
    <message>
        <source>This image has %1 KiB and exceeds recommended maximum size of %2 KiB. Some clients may have trouble with too large images.</source>
        <translation>Cette image a fait %1 ko et dépasse la taille maximale recommandé de %2 ko. Certains client pourraient rencontrer des problèmes avec des fichiers trop volumineux.</translation>
    </message>
    <message>
        <source>Do you really want to send this image?</source>
        <translation>Voulez vous vraiment envoyer cette image?</translation>
    </message>
</context>
<context>
    <name>GaduChatService</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Message too long (%1 &gt;= %2)</source>
        <translation>Message trop long (%1 &gt;= %2)</translation>
    </message>
</context>
<context>
    <name>GaduContactPersonalInfoWidget</name>
    <message>
        <source>First Name</source>
        <translation>Prénom</translation>
    </message>
    <message>
        <source>Last Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudonyme</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>Sexe</translation>
    </message>
    <message>
        <source>Birthdate</source>
        <translation>Date de naissance</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Ville</translation>
    </message>
    <message>
        <source>State/Province</source>
        <translation>Pays/Département</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Adresse IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>DNS Name</source>
        <translation>Nom du DNS</translation>
    </message>
    <message>
        <source>Protocol Version</source>
        <translation>Version du protocol</translation>
    </message>
    <message>
        <source>Female</source>
        <translation>Féminin</translation>
    </message>
    <message>
        <source>Male</source>
        <translation>Masculin</translation>
    </message>
</context>
<context>
    <name>GaduEditAccountWidget</name>
    <message>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulez</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>Supprimer le compte</translation>
    </message>
    <message>
        <source>Gadu-Gadu number</source>
        <translation>Numéro Gadu-Gadu</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Remember password</source>
        <translation>Rappeler le mot de passe</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Identité du compte</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Sélectionnez ou entrez l&apos;identité qui va être associé avec ce compte.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Personal info</source>
        <translation>Informations personnelles</translation>
    </message>
    <message>
        <source>Buddies</source>
        <translation>Amis</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Use default servers</source>
        <translation>Utiliser les serveurs par défaut</translation>
    </message>
    <message>
        <source>Use encrypted connection</source>
        <translation>Utiliser une connexion cryptée</translation>
    </message>
    <message>
        <source>Remove account</source>
        <translation>Supprimer un compte</translation>
    </message>
    <message>
        <source>External port</source>
        <translation>Port externe</translation>
    </message>
    <message>
        <source>You have to compile libgadu with SSL support to be able to enable encrypted connection</source>
        <translation>Vous devez compiler libgadu avec le support du SSL pour être en mesure de crypter la connexion</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Autres</translation>
    </message>
    <message>
        <source>Proxy configuration</source>
        <translation>Configuration du proxy</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Receive images also when I am Invisible</source>
        <translation>Recevoir les images même quand je suis invisible</translation>
    </message>
    <message>
        <source>Warn me when the image being sent may be too large</source>
        <translation>M&apos;avertir lorsque l&apos;image sur le point d&apos;être envoyé est trop volumineuse</translation>
    </message>
    <message>
        <source>Some clients may have trouble with too large images (over 256 KiB).</source>
        <translation>Certains clients pourraient rencontrer des problèmes avec une image trop volumineuse ( au dessus de 256Ko ).</translation>
    </message>
    <message>
        <source>Show my status only to buddies on my list</source>
        <translation>Afficher mon état seulement pour les contacts de ma liste</translation>
    </message>
    <message>
        <source>When disabled, anyone can see your status.</source>
        <translation>Quand désactivé, tout le monde peut voir mon état.</translation>
    </message>
    <message>
        <source>Enable composing events</source>
        <translation>Activer la génération d&apos;évènements</translation>
    </message>
    <message>
        <source>Your interlocutor will be notified when you are typing a message, before it is sent. And vice versa.</source>
        <translation>Votre interlocuteur va être notifié quand vous être en train de saisir un message, avant qu&apos;il soit envoyé. Et vice et versa.</translation>
    </message>
    <message>
        <source>Block links from anonymous buddies</source>
        <translation>Bloquer les liens des contacts anonymes</translation>
    </message>
    <message>
        <source>Protects you from potentially malicious links in messages from anonymous buddies</source>
        <translation>Vous protéger contre les menaces potentielles des liens dans les messages de la part de contacts anonymes</translation>
    </message>
    <message>
        <source>Gadu-Gadu Server</source>
        <translation>Serveur Gadu-Gadu</translation>
    </message>
    <message>
        <source>Custom server IP addresses</source>
        <translation>Adresses IP personnalisés serveur</translation>
    </message>
    <message>
        <source>Enable file transfers</source>
        <translation>Activer le transfert de fichiers</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Réseau IM</translation>
    </message>
    <message>
        <source>External IP</source>
        <translation>IP externe</translation>
    </message>
    <message>
        <source>Confrim Account Removal</source>
        <translation>Confirmer la suppression du compte</translation>
    </message>
    <message>
        <source>Are you sure do you want to remove account %1 (%2)?</source>
        <translation>Êtes vous certain de vouloir supprimer ce compte %1 (%2)</translation>
    </message>
    <message>
        <source>Status Visibility</source>
        <translation>Visibilité du statut</translation>
    </message>
    <message>
        <source>You are going to reveal your status to several buddies which are currently not allowed to see it.
Are you sure to allow them to know you are available?</source>
        <translation>Vous êtes sur le point de révéler votre état à de nombreux contacts qui ne sont actuellement pas autorisés à le voir.
Êtes vous sûr de vouloir les autoriser à voir lorsque vous êtes disponible ?</translation>
    </message>
    <message>
        <source>Make my status visible anyway</source>
        <translation>Mettre mon état visible malgrès tout</translation>
    </message>
    <message>
        <source>Stay with private status</source>
        <translation>Rester en occupé</translation>
    </message>
    <message>
        <source>Remind GG number</source>
        <translation>Mémoriser nombre GG</translation>
    </message>
    <message>
        <source>Remind Password</source>
        <translation>Mémoriser le mot de passe</translation>
    </message>
</context>
<context>
    <name>GaduPersonalInfoWidget</name>
    <message>
        <source>Unknown Gender</source>
        <translation>Sexe inconnu</translation>
    </message>
    <message>
        <source>Male</source>
        <translation>Masculin</translation>
    </message>
    <message>
        <source>Female</source>
        <translation>Féminin</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Pseudo</translation>
    </message>
    <message>
        <source>First name</source>
        <translation>Prénom</translation>
    </message>
    <message>
        <source>Last name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Sex</source>
        <translation>Sexe</translation>
    </message>
    <message>
        <source>Family name</source>
        <translation>Nom de famille</translation>
    </message>
    <message>
        <source>Birth year</source>
        <translation>Date de naissance</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Ville</translation>
    </message>
    <message>
        <source>Family city</source>
        <translation>Ville de la famille</translation>
    </message>
</context>
<context>
    <name>GaduProtocol</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
</context>
<context>
    <name>GaduProtocolFactory</name>
    <message>
        <source>Gadu-Gadu number:</source>
        <translation>Numéro Gadu-Gadu :</translation>
    </message>
</context>
<context>
    <name>GaduProtocolPlugin</name>
    <message>
        <source>Gadu-Gadu Protocol</source>
        <translation>Protocol Gadu-Gadu</translation>
    </message>
    <message>
        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
        <translation>Impossible de charger le module Gadu-Gadu. Veuillez Compiler libgadu avec le support de zlib.</translation>
    </message>
</context>
</TS>

==> kadu-3.0.tar.bz2: kadu-3.0/plugins/gadu_protocol/translations/gadu_protocol_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Unable to connect, server has not been found</source>
        <translation>Connexion impossible. Le serveur est introuvable</translation>
    </message>
    <message>
        <source>Unable to connect</source>
        <translation>Connexion impossible.</translation>
    </message>
    <message>
        <source>Please change your email in &quot;Change password / email&quot; window. Leave new password field blank.</source>
        <translation>Veuillez changer votre email dans la fenêtre &quot;changer mot de passe / email&quot;. Laissez le champ nouveau mot de passe à blanc.</translation>
    </message>
    <message>
        <source>Unable to connect, server has returned unknown data</source>
        <translation>Impossible de se connecter au serveur, le serveur a retourné des données inconnus</translation>
    </message>
    <message>
        <source>Unable to connect, connection break during reading</source>
        <translation>Impossible de se connecter au serveur, la connexion a été interrompu pendant la lecture</translation>
    </message>
    <message>
        <source>Unable to connect, connection break during writing</source>
        <translation>Impossible de se connecter au serveur, la connexion a été interrompu pendant la l&apos;écriture</translation>
    </message>
    <message>
        <source>Unable to connect, invalid password</source>
        <translation>Impossible de se connecter au serveur, mot de passe non valide</translation>
    </message>
    <message>
        <source>Unable to connect, error of negotiation TLS</source>
        <translation>Impossible de se connecter au serveur, erreur de négociation TLS</translation>
    </message>
    <message>
        <source>Too many connection attempts with bad password!</source>
        <translation>Trop de tentatives de connexions avec un mot de passe incorrect!</translation>
    </message>
    <message>
        <source>Unable to connect, servers are down</source>
        <translation>Impossible de se connecter au serveur, le serveur est indisponible</translation>
    </message>
    <message>
        <source>Connection broken</source>
        <translation>Connexion interrompue</translation>
    </message>
    <message>
        <source>Connection timeout!</source>
        <translation>délai de connexion!</translation>
    </message>
    <message>
        <source>Disconnection has occurred</source>
        <translation>Une déconnexion s&apos;est produite</translation>
    </message>
</context>
<context>
    <name>GaduAddAccountWidget</name>
    <message>
        <source>Gadu-Gadu number</source>
        <translation>Numéro Gadu-Gadu</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Remember Password</source>
        <translation>Rappeler le mot de passe</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Identité du compte</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt; Sélectionnez ou entrez l&apos;identité qui va être associée avec le compte &lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>Add Account</source>
        <translation>Ajouter un compte</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulez</translation>
    </message>
    <message>
        <source>Register Account</source>
        <translation>Inscription de compte</translation>
    </message>
    <message>
        <source>Remind GG number</source>
        <translation>Mémoriser nombre GG</translation>
    </message>
    <message>
        <source>Remind Password</source>
        <translation>Retenir le mot de passe</translation>
    </message>
</context>
<context>
    <name>GaduChatImageService</name>
    <message>
        <source>This image has %1 KiB and exceeds recommended maximum size of %2 KiB. Some clients may have trouble with too large images.</source>
        <translation>Cette image a fait %1 ko et dépasse la taille maximale recommandé de %2 ko. Certains client pourraient rencontrer des problèmes avec des fichiers trop volumineux.</translation>
    </message>
    <message>
        <source>Do you really want to send this image?</source>
        <translation>Voulez vous vraiment envoyer cette image?</translation>
    </message>
</context>
<context>
    <name>GaduChatService</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Message too long (%1 &gt;= %2)</source>
        <translation>Message trop long (%1 &gt;= %2)</translation>
    </message>
</context>
<context>
    <name>GaduContactPersonalInfoWidget</name>
    <message>
        <source>First Name</source>
        <translation>Prénom</translation>
    </message>
    <message>
        <source>Last Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Pseudonyme</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>Sexe</translation>
    </message>
    <message>
        <source>Birthdate</source>
        <translation>Date de naissance</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Ville</translation>
    </message>
    <message>
        <source>State/Province</source>
        <translation>Pays/Département</translation>
    </message>
    <message>
        <source>Female</source>
        <translation>Féminin</translation>
    </message>
    <message>
        <source>Male</source>
        <translation>Masculin</translation>
    </message>
</context>
<context>
    <name>GaduEditAccountWidget</name>
    <message>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulez</translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation>Supprimer le compte</translation>
    </message>
    <message>
        <source>Gadu-Gadu number</source>
        <translation>Numéro Gadu-Gadu</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Remember password</source>
        <translation>Rappeler le mot de passe</translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation>Identité du compte</translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Sélectionnez ou entrez l&apos;identité qui va être associé avec ce compte.&lt;/i&gt;&lt;/font&gt;</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <source>Personal info</source>
        <translation>Informations personnelles</translation>
    </message>
    <message>
        <source>Buddies</source>
        <translation>Amis</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Use default servers</source>
        <translation>Utiliser les serveurs par défaut</translation>
    </message>
    <message>
        <source>Use encrypted connection</source>
        <translation>Utiliser une connexion cryptée</translation>
    </message>
    <message>
        <source>Remove account</source>
        <translation>Supprimer un compte</translation>
    </message>
    <message>
        <source>You have to compile libgadu with SSL support to be able to enable encrypted connection</source>
        <translation>Vous devez compiler libgadu avec le support du SSL pour être en mesure de crypter la connexion</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Autres</translation>
    </message>
    <message>
        <source>Proxy configuration</source>
        <translation>Configuration du proxy</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Images</translation>
    </message>
    <message>
        <source>Receive images also when I am Invisible</source>
        <translation>Recevoir les images même quand je suis invisible</translation>
    </message>
    <message>
        <source>Warn me when the image being sent may be too large</source>
        <translation>M&apos;avertir lorsque l&apos;image sur le point d&apos;être envoyé est trop volumineuse</translation>
    </message>
    <message>
        <source>Some clients may have trouble with too large images (over 256 KiB).</source>
        <translation>Certains clients pourraient rencontrer des problèmes avec une image trop volumineuse ( au dessus de 256Ko ).</translation>
    </message>
    <message>
        <source>Show my status only to buddies on my list</source>
        <translation>Afficher mon état seulement pour les contacts de ma liste</translation>
    </message>
    <message>
        <source>When disabled, anyone can see your status.</source>
        <translation>Quand désactivé, tout le monde peut voir mon état.</translation>
    </message>
    <message>
        <source>Enable composing events</source>
        <translation>Activer la génération d&apos;évènements</translation>
    </message>
    <message>
        <source>Your interlocutor will be notified when you are typing a message, before it is sent. And vice versa.</source>
        <translation>Votre interlocuteur va être notifié quand vous être en train de saisir un message, avant qu&apos;il soit envoyé. Et vice et versa.</translation>
    </message>
    <message>
        <source>Block links from anonymous buddies</source>
        <translation>Bloquer les liens des contacts anonymes</translation>
    </message>
    <message>
        <source>Protects you from potentially malicious links in messages from anonymous buddies</source>
        <translation>Vous protéger contre les menaces potentielles des liens dans les messages de la part de contacts anonymes</translation>
    </message>
    <message>
        <source>Gadu-Gadu Server</source>
        <translation>Serveur Gadu-Gadu</translation>
    </message>
    <message>
        <source>Custom server IP addresses</source>
        <translation>Adresses IP personnalisés serveur</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Réseau IM</translation>
    </message>
    <message>
        <source>Confrim Account Removal</source>
        <translation>Confirmer la suppression du compte</translation>
    </message>
    <message>
        <source>Are you sure do you want to remove account %1 (%2)?</source>
        <translation>Êtes vous certain de vouloir supprimer ce compte %1 (%2)</translation>
    </message>
    <message>
        <source>Status Visibility</source>
        <translation>Visibilité du statut</translation>
    </message>
    <message>
        <source>You are going to reveal your status to several buddies which are currently not allowed to see it.
Are you sure to allow them to know you are available?</source>
        <translation>Vous êtes sur le point de révéler votre état à de nombreux contacts qui ne sont actuellement pas autorisés à le voir.
Êtes vous sûr de vouloir les autoriser à voir lorsque vous êtes disponible ?</translation>
    </message>
    <message>
        <source>Make my status visible anyway</source>
        <translation>Mettre mon état visible malgrès tout</translation>
    </message>
    <message>
        <source>Stay with private status</source>
        <translation>Rester en occupé</translation>
    </message>
    <message>
        <source>Remind GG number</source>
        <translation>Mémoriser nombre GG</translation>
    </message>
    <message>
        <source>Remind Password</source>
        <translation>Mémoriser le mot de passe</translation>
    </message>
</context>
<context>
    <name>GaduFileTransferService</name>
    <message>
        <source>Connect before sending files.</source>
        <translation>Se connecter avant d&apos;envoyer des fichiers.</translation>
    </message>
    <message>
        <source>Enable SSL in account configuration and reconnect before sending files.</source>
        <translation>Activer SSL dans la configuration des comptes et se reconnecter avant d&apos;envoyer des fichiers.</translation>
    </message>
    <message>
        <source>Unable to login to GG Drive. Reconnect before sending files.</source>
        <translation>Impossible de se connecter au GG drive. Se reconnecter avant d&apos;envoyer des fichiers.</translation>
    </message>
</context>
<context>
    <name>GaduOutgoingFileTransferHandler</name>
    <message>
        <source>Valid GG Drive ticket not available</source>
        <translation>Le ticket de validation du GG drive n&apos;est pas disponible.</translation>
    </message>
</context>
<context>
    <name>GaduPersonalInfoWidget</name>
    <message>
        <source>Unknown Gender</source>
        <translation>Sexe inconnu</translation>
    </message>
    <message>
        <source>Male</source>
        <translation>Masculin</translation>
    </message>
    <message>
        <source>Female</source>
        <translation>Féminin</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Pseudo</translation>
    </message>
    <message>
        <source>First name</source>
        <translation>Prénom</translation>
    </message>
    <message>
        <source>Last name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Sex</source>
        <translation>Sexe</translation>
    </message>
    <message>
        <source>Family name</source>
        <translation>Nom de famille</translation>
    </message>
    <message>
        <source>Birth year</source>
        <translation>Date de naissance</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Ville</translation>
    </message>
    <message>
        <source>Family city</source>
        <translation>Ville de la famille</translation>
    </message>
</context>
<context>
    <name>GaduProtocol</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
</context>
<context>
    <name>GaduProtocolFactory</name>
    <message>
        <source>Gadu-Gadu number:</source>
        <translation>Numéro Gadu-Gadu :</translation>
    </message>
</context>
<context>
    <name>GaduProtocolPlugin</name>
    <message>
        <source>Gadu-Gadu Protocol</source>
        <translation>Protocol Gadu-Gadu</translation>
    </message>
    <message>
        <source>Cannot load Gadu-Gadu Protocol plugin. Please compile libgadu with zlib support.</source>
        <translation>Impossible de charger le module Gadu-Gadu. Veuillez Compiler libgadu avec le support de zlib.</translation>
    </message>
</context>
<context>
    <name>GaduSendGiftAction</name>
    <message>
        <source>Send Gift...</source>
        <translation>Envoyer Surprise...</translation>
    </message>
</context>
<context>
    <name>GaduUrlIncomingFileTransferHandler</name>
    <message>
        <source>Network error: %1</source>
        <translation>Erreur réseau: %1</translation>
    </message>
</context>
</TS>
